@@ -13,13 +13,26 @@ our @ISA = 'Regexp';
 
 BEGIN
 {
-  our $VERSION = '0.006'; # VERSION
+  our $VERSION = '0.007'; # VERSION
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
 sub import
 {
+    my $class = shift;
+
     $^H{regcomp} = ENGINE;
+
+    if (@_) {
+      my %args = @_;
+      if (exists $args{'-debug'}) {
+        $^H{__PACKAGE__ . '::debug'} = $args{'-debug'};
+      }
+      if (exists $args{'-syntax'}) {
+        $^H{__PACKAGE__ . '::syntax'} = $args{'-syntax'};
+      }
+    }
+
 }
 
 sub unimport
@@ -30,13 +43,6 @@ sub unimport
       delete($^H{regcomp});
     }
 
-    if (@_) {
-      my %args = @_;
-      if (exists $args{'debug'}) {
-        $^H{__PACKAGE__ . '::debug'} = $args{'debug'};
-      }
-    }
-
 }
 
 1;
@@ -53,7 +59,7 @@ re::engine::GNU - GNU Regular Expression Engine
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -64,9 +70,21 @@ version 0.006
 
 =head1 DESCRIPTION
 
-The GNU regular expression engine plugged into perl.
+The GNU regular expression engine plugged into perl. The package can be "used" with the following pragmas:
 
-They can be writen in three form:
+=over
+
+=item -debug => boolean
+
+E.g. use re::engine::GNU -debug => 1;    # a true value will print on stderr
+
+=item -syntax => bitwised value
+
+E.g. use re::engine::GNU -syntax => 0;   # Default syntax. Useful for the // form.
+
+=back
+
+Regular expressions can be writen in three form:
 
 =over
 
@@ -100,18 +118,6 @@ http://www.regular-expressions.info/gnu.html
 
 =head1 AUTHOR
 
-Jean-Damien Durand.
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2015 by Jean-Damien Durand.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.20.1 or,
-at your option, any later version of Perl 5 you may have available.
-
-=head1 AUTHOR
-
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
 =head1 COPYRIGHT AND LICENSE
